pub struct SpannedToken {
pub token: Token,
pub span: Span,
pub byte_start: usize,
pub byte_end: usize,
}Fields
token: Tokenspan: Spanbyte_start: usizeByte offset of the start of this token in the source string.
byte_end: usizeByte offset past the end of this token in the source string.